@@ -13,7 +13,6 @@ PN_SUBSCRIBE_KEY = "sub-c-6fb03d68-6a78-11e2-ae8f-12313f022c90"
 PN_CHANNEL = "PlatformChannel"
 
 _LOGGER = logging.getLogger(__name__)
-OUTPUT_FILE = ".pubnub.log"
 
 
 class VivintPubNubSubscribeListener(SubscribeCallback):
@@ -52,8 +51,6 @@ class VivintPubNubSubscribeListener(SubscribeCallback):
         message: PNMessageResult,
     ) -> None:
         """Handle a message received."""
-        with open(OUTPUT_FILE, "a", encoding="utf-8") as f:
-            f.write(f"{message.timetoken}: {message.message}\n")
         self.__message_received_callback(message.message)
 
 
@@ -122,7 +119,9 @@ class PubNubOperationType(IntEnum):
     FIRE = 25
     SIGNAL = 26
 
+    ACCESS_MANAGER_REVOKE_TOKEN = 40
     ACCESS_MANAGER_GRANT_TOKEN = 41
+
     ADD_MESSAGE_ACTION = 42
     GET_MESSAGE_ACTIONS = 43
     DELETE_MESSAGE_ACTION = 44
